@@ -1,6 +1,9 @@
-
 from kii.app import core
 
+
 class App(core.App):
     name = "kii.glue"
-    urls = ".urls"
\ No newline at end of file
+    urls = ".urls"
+
+    def get_url_prefix(self):
+        return r'^$'
\ No newline at end of file
