@@ -1,9 +1,15 @@
+from django.conf import settings
+
 import kii
 
 
 def kii_metadata(request):
-    """TODO : is user_access really needed ?"""
     return {
         'kii_version': kii.__version__,
         'kii_project_url': kii.PROJECT_URL,
     }
+
+def tracking_code(request):
+    return {
+        'tracking_code': settings.TRACKING_CODE,
+    }
\ No newline at end of file
