@@ -1,7 +1,7 @@
 from kii.base_models import views
 from . import models, filterset
 
-class OwnerModelList(views.OwnerMixin, views.List):
+class OwnerModelList(views.List):
     model = models.OwnerModel
 
 
