@@ -4,5 +4,5 @@ from . import views
 
 urlpatterns = patterns('',
     url(r'^login$', views.login, name="login"), # NOQA
-    url(r'^logout$', views.logout, name="logout"),
+    url(r'^logout$', views.logout, {'next_page': '/'}, name="logout"),
 )
